@@ -26,9 +26,6 @@ JOURNAL_RETRIES = 10
 JOURNAL_SLEEP_TIME = 60
 
 
-DEBUG_REVISION = None
-
-
 class UpdateNotifier:
     def __init__(self, *, sleep_time: float = 3_600, delete_old_revisions: bool = True):
         self.sleep_time = sleep_time
@@ -81,10 +78,11 @@ class UpdateNotifier:
                     wad_url = base_url + "/" + name
                     journal_crcs = self._get_wad_journal(wad_url)
 
-                    for inner_file, (crc, size, compressed_size, is_compressed) in journal_crcs.items():
+                    for inner_file, (file_offset, crc, size, compressed_size, is_compressed) in journal_crcs.items():
                         logger.debug(f"Filling db with wad inner file {inner_file}")
 
                         self.db.add_wad_file_info(
+                            file_offset,
                             crc,
                             size,
                             compressed_size,
@@ -104,9 +102,6 @@ class UpdateNotifier:
             if self.db.check_if_new_revision(revision):
                 self.new_revision(revision, file_list_url, base_url)
 
-            elif DEBUG_REVISION:
-                self.new_revision(DEBUG_REVISION, file_list_url, base_url)
-
             else:
                 logger.info(f"No new revision found")
 
@@ -158,6 +153,7 @@ class UpdateNotifier:
         )
 
         new_file_names = []
+        unchanged_wads = []
 
         for table_name, records in records.items():
             # meta tables
@@ -261,14 +257,16 @@ class UpdateNotifier:
 
                 else:
                     if name.endswith(".wad"):
-                        # this is so the wad inner files are updated to the latest revision
-                        self.db.update_wad_file_infos_revision_with_wad_name(name, new_revision)
+                        unchanged_wads.append(name)
 
                 # need to be versioned even if unchanged
                 self.db.add_versioned_file_info(
                     record["CRC"], record["Size"], new_revision, record["SrcFileName"]
                 )
 
+        # this is so the wad inner files are updated to the latest revision
+        self.db.mass_update_wad_file_infos_revision_with_wad_names(unchanged_wads, new_revision)
+
         self.db.commit()
 
         for crc, size, revision, name in last_revision_files:
@@ -280,14 +278,15 @@ class UpdateNotifier:
                         deleted_inner_files.append(
                             #  0 crc, 1 size_, 2 name, 3 file_offset, 4 compressed_size, 5 is_compressed
                             WadInnerFileInfo(
-                                inner_file[2],
-                                name,
-                                0,
-                                0,
-                                inner_file[4],
-                                inner_file[5],
-                                inner_file[1],
-                                inner_file[0]
+                                name=inner_file[2],
+                                wad_name=name,
+                                size=0,
+                                crc=0,
+                                compressed_size=inner_file[4],
+                                is_compressed=inner_file[5],
+                                file_offset=inner_file[3],
+                                old_size=inner_file[1],
+                                old_crc=inner_file[0],
                             )
                         )
 
@@ -327,18 +326,19 @@ class UpdateNotifier:
         created_inner_files = []
         changed_inner_files = []
 
-        for inner_file, (crc, size, compressed_size, is_compressed) in journal_crcs.items():
+        for inner_file, (file_offset, crc, size, compressed_size, is_compressed) in journal_crcs.items():
             res, (old_crc, old_size) = self.db.check_if_wad_file_updated(crc, size, old_revision, inner_file, wad_name)
 
             inner_file_info = WadInnerFileInfo(
-                inner_file,
-                wad_name,
-                size,
-                crc,
-                compressed_size,
-                is_compressed,
-                old_size,
-                old_crc
+                name=inner_file,
+                wad_name=wad_name,
+                size=size,
+                crc=crc,
+                compressed_size=compressed_size,
+                is_compressed=is_compressed,
+                file_offset=file_offset,
+                old_size=old_size,
+                old_crc=old_crc
             )
 
             # TODO: 3.10 switch to match
@@ -353,6 +353,7 @@ class UpdateNotifier:
                 pass
 
             self.db.add_wad_file_info(
+                file_offset,
                 crc,
                 size,
                 compressed_size,
@@ -369,14 +370,15 @@ class UpdateNotifier:
                 deleted_inner_files.append(
                     #  0 crc, 1 size_, 2 name, 3 file_offset, 4 compressed_size, 5 is_compressed
                     WadInnerFileInfo(
-                        inner_file[2],
-                        wad_name,
-                        0,
-                        0,
-                        inner_file[4],
-                        inner_file[5],
-                        inner_file[1],
-                        inner_file[0]
+                        name=inner_file[2],
+                        wad_name=wad_name,
+                        size=0,
+                        crc=0,
+                        compressed_size=inner_file[4],
+                        is_compressed=inner_file[5],
+                        file_offset=inner_file[3],
+                        old_size=inner_file[1],
+                        old_crc=inner_file[0],
                     )
                 )
 
